@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from maser.script import main
-from maser.utils.cdf import validator, converter, cdfcompare
+from maser.utils.cdf import validator, serializer, cdfcompare
 from maser.utils.time import tt2000_to_jd, local_to_utc, mjd_to_jd, jd_to_mjd
-from maser.settings import SUPPORT_DIR, DATA_DIR
+from maser.settings import *
 from maser.data import *
