@@ -6,16 +6,17 @@ Python module to read a Wind/Waves data file from CDPP deep archive (http://cdpp
 @author: B.Cecconi(LESIA)
 """
 
-import struct
-import os
-from maser.data.cdpp import CDPPDataFromFile
-
 __author__ = "Baptiste Cecconi"
 __date__ = "10-JUL-2017"
 __version__ = "0.11"
 
 __all__ = ["WindWavesData", "read_wind_waves"]
 
+import struct
+import os
+from maser.data.cdpp import CDPPDataFromFile
+from .const import *
+
 
 class WindWavesData(CDPPDataFromFile):
     """
@@ -129,8 +130,7 @@ def read_wind_waves_nn(file_path, verbose=False):
                 nsweep += 1
 
     name = 'WIND_WAVES_TNR_L3_NN'
-    meta = {"PLASMA_FREQ": {"unit": "kHz", "description": "Plasma Frequency from Neural Network"},
-            "ELEC_DENSITY": {"unit": "cm-3", "description": "Electronic Density from Neural Network"}}
+    meta = WIND_WAVES_TNR_L3_NN_META
 
     return WindWavesData(os.path.basename(file_path), header, data, name, meta)
 
@@ -236,35 +236,7 @@ def read_wind_waves_bqt(file_path, verbose=False):
                 nsweep += 1
 
     name = 'WIND_WAVES_TNR_L3_BQT'
-
-    meta = {"PLASMA_FREQUENCY_NN":
-            {"unit": "kHz", "description": "Plasma Frequency from Neural Network"},
-            "PLASMA_FREQUENCY":
-            {"unit": "kHz", "description": "Plasma Frequency from Fit"},
-            "COLD_ELECTRONS_TEMPERATURE":
-            {"unit": "eV", "description": "Cold Electron Temperature from Fit"},
-            "ELECTRONIC_DENSITY_RATIO":
-            {"unit": "N/A", "description": "Electronic Density Ratio from Fit"},
-            "ELECTRONIC_TEMPERATURE_RATIO":
-            {"unit": "N/A", "description": "Electronic Temperature Ratio from Fit"},
-            "PROTON_TEMPERATURE":
-            {"unit": "eV", "description": "Proton Temperature from 3DP"},
-            "SOLAR_WIND_VELOCITY":
-            {"unit": "km/s", "description": "Solar Wind Velocity from 3DP"},
-            "FIT_ACCUR_PARAM_1":
-            {"unit": "%", "description": "Fit Accuracy on PLASMA_FREQUENCY (0.0 if not fitted)"},
-            "FIT_ACCUR_PARAM_2":
-            {"unit": "%", "description": "Fit Accuracy on COLD_ELECTRONS_TEMPERATURE (0.0 if not fitted)"},
-            "FIT_ACCUR_PARAM_3":
-            {"unit": "%", "description": "Fit Accuracy on ELECTRONIC_DENSITY_RATIO (0.0 if not fitted)"},
-            "FIT_ACCUR_PARAM_4":
-            {"unit": "%", "description": "Fit Accuracy on ELECTRONIC_TEMPERATURE_RATIO (0.0 if not fitted)"},
-            "FIT_ACCUR_PARAM_7":
-            {"unit": "%", "description": "Fit Accuracy on PROTON_TEMPERATURE (0.0 if not fitted)"},
-            "FIT_ACCUR_PARAM_8":
-            {"unit": "%", "description": "Fit Accuracy on SOLAR_WIND_VELOCITY (0.0 if not fitted)"},
-            "FIT_ACCUR_RMS":
-            {"unit": "%", "description": "Root mean square between measured and fitted spectra"}}
+    meta = WIND_WAVES_TNR_L3_BQT_META
 
     return WindWavesData(os.path.basename(file_path), header, data, name, meta)
 
@@ -354,9 +326,7 @@ def read_wind_waves_radio_60s(file_path, verbose=False):
                 nsweep += 1
 
     name = 'WIND_WAVES_RADIO_60S'
-
-    meta = {"FREQ": {"unit": "kHz", "description": "Frequency"},
-            "INTENSITY": {"unit": "uV^2/Hz", "description": "Intensity"}}
+    meta = WIND_WAVES_RADIO_60S_META
 
     return WindWavesData(os.path.basename(file_path), header, data, name, meta)
 
