@@ -3,7 +3,7 @@
 
 from maser.utils.cdf.cdf import const
 from maser.utils.cdf.cdf import *
-from maser.utils.cdf.converter import skeletoncdf, SkeletonCDFException
+from maser.utils.cdf.serializer import skeletoncdf
 from maser.utils.cdf.validator import Validate
 from maser.utils.cdf.tools import get_cdftype, get_vattrs, \
     get_cdftypename, get_numpttype
